import terser from '@rollup/plugin-terser';
import type { OutputOptions, ModuleFormat } from 'rollup';

export const getOutputOptions = (
  globals: Record<string, string>,
  isAnalyze: boolean,
  isDev: boolean,
  packageName: string,
): OutputOptions[] => {
  const unminified = {
    file: `dist/${packageName}.js`,
    format: 'esm' as ModuleFormat,
    globals,
  };
  const minified = {
    file: `dist/${packageName}.min.js`,
    format: 'esm' as ModuleFormat,
    plugins: [terser()],
    globals,
  };
  const iife = {
    file: `dist/${packageName}.iife.min.js`,
    format: 'iife' as ModuleFormat,
    plugins: [terser()],
    globals,
  };

  if (isDev) {
    return [unminified];
  } else if (isAnalyze) {
    return [minified];
  } else {
    return [unminified, minified, iife];
  }
};
